summaryrefslogtreecommitdiff
path: root/state.go
diff options
context:
space:
mode:
Diffstat (limited to 'state.go')
-rw-r--r--state.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/state.go b/state.go
index 8fbc7d2..1f9f52c 100644
--- a/state.go
+++ b/state.go
@@ -108,7 +108,7 @@ func (state *VPNState) Connect(url string) (string, error) {
// Make sure we are in the chosen state if available
state.FSM.GoTransition(internal.CHOSEN_SERVER)
// Relogin with oauth
// This moves the state to authenticated
if server.NeedsRelogin() {
loginErr := server.Login()
@@ -118,8 +118,8 @@ func (state *VPNState) Connect(url string) (string, error) {
state.FSM.GoTransition(internal.CHOSEN_SERVER)
return "", loginErr
}
- } else { // OAuth was valid, ensure we are in the authenticated state
- state.FSM.GoTransition(internal.AUTHENTICATED)
+ } else { // OAuth was valid, ensure we are in the authorized state
+ state.FSM.GoTransition(internal.AUTHORIZED)
}
state.FSM.GoTransition(internal.REQUEST_CONFIG)
@@ -108,7 +108,7 @@ func (state *VPNState) Connect(url string) (string, error) {
state.FSM.GoTransition(internal.CHOSEN_SERVER)
// Relogin with oauth
- // This moves the state to authenticated
+ // This moves the state to authorized
if server.NeedsRelogin() {
loginErr := server.Login()